@@ -24,16 +24,15 @@ main (int argc, char *argv[])
   GArgument retval;
   gint res;
   gchar *blurb;
-  gint len;
+  guint len;
   GError *error = NULL;
-  const gchar *name;
   TestStruct *s;
   
   g_type_init ();
 
   rep = g_irepository_get_default ();
 
-  g_assert (!g_irepository_is_registered (NULL, "test", NULL));
+  g_assert (!g_irepository_is_registered (NULL, "testfns", NULL));
   
   handle = g_module_open (testfns, 0);
   if (!handle)
@@ -42,17 +41,19 @@ main (int argc, char *argv[])
       return 1;
     }
 
-  g_assert (g_irepository_is_registered (NULL, "test", NULL));
+  g_assert (g_irepository_is_registered (NULL, "testfns", NULL));
 
+#if 0
   g_print ("after dlopening %s: %d infos in the repository\n", 
 	   testfns,
-	   g_irepository_get_n_infos (rep, "test"));
+	   g_irepository_get_n_infos (rep, "testfns"));
+#endif
 
   /* test1 calculates x + 4, 
    * taking x as an in parameter
    * and returning the result 
    */
-  info = g_irepository_find_by_name (rep, "test", "test1");  
+  info = g_irepository_find_by_name (rep, "testfns", "test1");  
   g_assert (g_base_info_get_type (info) == GI_INFO_TYPE_FUNCTION);
   function = (GIFunctionInfo *)info;
 
@@ -70,7 +71,7 @@ main (int argc, char *argv[])
    * taking x as an in parameter
    * and storing the result in an out parameter
    */
-  info = g_irepository_find_by_name (rep, "test", "test2");  
+  info = g_irepository_find_by_name (rep, "testfns", "test2");  
   g_assert (g_base_info_get_type (info) == GI_INFO_TYPE_FUNCTION);
   function = (GIFunctionInfo *)info;
 
@@ -89,7 +90,7 @@ main (int argc, char *argv[])
    * taking x as an inout parameter
    * and storing the result in the same parameter
    */
-  info = g_irepository_find_by_name (rep, "test", "test3");  
+  info = g_irepository_find_by_name (rep, "testfns", "test3");  
   g_assert (g_base_info_get_type (info) == GI_INFO_TYPE_FUNCTION);
   function = (GIFunctionInfo *)info;
 
@@ -105,7 +106,7 @@ main (int argc, char *argv[])
 
   /* test4 prints out a string
    */
-  info = g_irepository_find_by_name (rep, "test", "test4");  
+  info = g_irepository_find_by_name (rep, "testfns", "test4");  
   g_assert (g_base_info_get_type (info) == GI_INFO_TYPE_FUNCTION);
   function = (GIFunctionInfo *)info;
 
@@ -119,7 +120,7 @@ main (int argc, char *argv[])
 
   /* test5 returns a string and a length
    */
-  info = g_irepository_find_by_name (rep, "test", "test5");  
+  info = g_irepository_find_by_name (rep, "testfns", "test5");  
   g_assert (g_base_info_get_type (info) == GI_INFO_TYPE_FUNCTION);
   function = (GIFunctionInfo *)info;
 
@@ -139,7 +140,7 @@ main (int argc, char *argv[])
 
   /* test GList*/
   g_print ("Test 6\n");
-  info = g_irepository_find_by_name (rep, "test", "test6");
+  info = g_irepository_find_by_name (rep, "testfns", "test6");
   g_assert (g_base_info_get_type (info) == GI_INFO_TYPE_FUNCTION);
   function = (GIFunctionInfo *)info;
 
@@ -164,7 +165,7 @@ main (int argc, char *argv[])
 
   /* test GList more, transfer ownership*/
   g_print ("Test 7\n");
-  info = g_irepository_find_by_name (rep, "test", "test7");
+  info = g_irepository_find_by_name (rep, "testfns", "test7");
   g_assert (g_base_info_get_type (info) == GI_INFO_TYPE_FUNCTION);
   function = (GIFunctionInfo *)info;
 
@@ -179,7 +180,7 @@ main (int argc, char *argv[])
 	       g_base_info_get_name (info),
 	       error->message);
 
-    g_print("returned %s\n", retval.v_pointer);
+    g_print("returned %p\n", retval.v_pointer);
     g_assert (strcmp(retval.v_pointer, "Hey there...")==0);
     g_list_foreach (list, (GFunc) g_free, NULL);
     g_list_free (list);
@@ -194,13 +195,13 @@ main (int argc, char *argv[])
   g_clear_error (&error);
 
   g_print("Test 8\n");
-  info = g_irepository_find_by_name (rep, "test", "TestStruct");
+  info = g_irepository_find_by_name (rep, "testfns", "TestStruct");
   g_assert (g_base_info_get_type (info) == GI_INFO_TYPE_STRUCT);
   record = (GIStructInfo *)info;
-  info = g_struct_info_find_method (record, "test8");
+  info = (GIBaseInfo*)g_struct_info_find_method (record, "test8");
   g_assert (g_base_info_get_type (info) == GI_INFO_TYPE_FUNCTION);
   function = (GIFunctionInfo *)info;
-  g_assert (g_function_info_get_flags (info) & GI_FUNCTION_IS_CONSTRUCTOR);
+  g_assert (g_function_info_get_flags (function) & GI_FUNCTION_IS_CONSTRUCTOR);
 
   {
     in_args[0].v_int = 42;
@@ -221,10 +222,10 @@ main (int argc, char *argv[])
   g_clear_error (&error);
 
   g_print("Test 9\n");
-  info = g_struct_info_find_method (record, "test9");
+  info = (GIBaseInfo*)g_struct_info_find_method (record, "test9");
   g_assert (g_base_info_get_type (info) == GI_INFO_TYPE_FUNCTION);
   function = (GIFunctionInfo *)info;
-  g_assert (g_function_info_get_flags (info) & GI_FUNCTION_IS_METHOD);
+  g_assert (g_function_info_get_flags (function) & GI_FUNCTION_IS_METHOD);
 
   {
     TestStruct s = { 42 };
@@ -242,7 +243,7 @@ main (int argc, char *argv[])
   }
 
   g_base_info_unref (info);
-  g_base_info_unref (record);
+  g_base_info_unref ((GIBaseInfo*)record);
   g_clear_error (&error);
 
 
@@ -250,7 +251,7 @@ main (int argc, char *argv[])
 
 #if 0
   /* "broken" is in the typelib but not in the .so*/
-  info = g_irepository_find_by_name (rep, "test", "broken");  
+  info = g_irepository_find_by_name (rep, "testfns", "broken");  
   g_assert (g_base_info_get_type (info) == GI_INFO_TYPE_FUNCTION);
   function = (GIFunctionInfo *)info;
 
@@ -262,9 +263,9 @@ main (int argc, char *argv[])
   g_base_info_unref (info);
   g_clear_error (&error);
 #endif
-  
+
   /* too few in arguments */
-  info = g_irepository_find_by_name (rep, "test", "test2");  
+  info = g_irepository_find_by_name (rep, "testfns", "test2");  
   g_assert (g_base_info_get_type (info) == GI_INFO_TYPE_FUNCTION);
   function = (GIFunctionInfo *)info;
 
